@@ -86,7 +86,7 @@
 #define KGLOBALACCELPRIVATE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED
-#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -187,7 +187,7 @@
 #define KGLOBALACCELPRIVATE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED
-#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0
@@ -197,7 +197,7 @@
 #  ifdef KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
